import pytest
from quixote import cleanup

from wcs.formdef import FormDef
from wcs.workflows import Workflow

from ..utilities import clean_temporary_pub, create_temporary_pub, get_app


def setup_module(module):
    cleanup()


def teardown_module(module):
    clean_temporary_pub()


@pytest.fixture
def pub():
    pub = create_temporary_pub()
    pub.cfg['language'] = {'language': 'en'}
    pub.write_cfg()
    return pub


def test_editable_line_details(pub):
    workflow = Workflow(name='test')
    st1 = workflow.add_status('Status1', 'st1')
    action = st1.add_action('editable')

    assert action.get_line_details() == 'not completed'

    role = pub.role_class(name='foorole')
    role.store()
    action.by = [role.id]
    assert action.get_line_details() == '"Edit Form", by foorole'

    action.label = 'foobar'
    assert action.get_line_details() == '"foobar", by foorole'


def test_editable_set_marker(pub):
    FormDef.wipe()
    Workflow.wipe()

    workflow = Workflow(name='test')
    st1 = workflow.add_status('Status1', 'st1')
    st2 = workflow.add_status('Status2', 'st2')
    editable = st1.add_action('editable')
    editable.status = st2.id
    editable.set_marker_on_status = True
    editable.by = ['_submitter']
    back = st2.add_action('choice')
    back.label = 'go back'
    back.status = '_previous'
    back.by = ['_submitter']
    workflow.store()

    formdef = FormDef()
    formdef.name = 'baz'
    formdef.workflow = workflow
    formdef.store()

    resp = get_app(pub).get(formdef.get_url())
    resp = resp.form.submit('submit')  # -> validation page
    resp = resp.form.submit('submit').follow()  # -> done
    formdata = formdef.data_class().select()[0]

    # edit
    resp = resp.form.submit(f'button{editable.id}').follow()
    resp = resp.form.submit('submit').follow()  # -> done

    formdata.refresh_from_storage()
    assert formdata.get_status().id == st2.id
    assert formdata.workflow_data.get('_markers_stack')

    # back
    resp = resp.form.submit(f'button{editable.id}').follow()
    formdata.refresh_from_storage()
    assert formdata.get_status().id == st1.id
    assert not formdata.workflow_data.get('_markers_stack')
